@@ -1,9 +1,3 @@
-//! Rust Daml type code generator.
-//!
-//! Provides an implementation of custom attributes and procedural macros defined in the [`daml-derive`] crate.
-//!
-//! [`daml-derive`]: https://docs.rs/daml-derive
-
 #![warn(clippy::all, clippy::pedantic, clippy::nursery, rust_2018_idioms)]
 #![allow(
     clippy::module_name_repetitions,
@@ -16,12 +10,16 @@
 #![forbid(unsafe_code)]
 #![doc(html_favicon_url = "https://docs.daml.com/_static/images/favicon/favicon-32x32.png")]
 #![doc(html_logo_url = "https://docs.daml.com/_static/images/DAML_Logo_Blue.svg")]
-#![doc(html_root_url = "https://docs.rs/daml-codegen/0.1.1")]
+#![doc(html_root_url = "https://docs.rs/daml-codegen/0.2.1")]
 #![recursion_limit = "128"]
+// importing the crate README as the rust doc breaks the link to the LICENCE file.
+#![allow(rustdoc::broken_intra_doc_links)]
+#![doc = include_str!("../README.md")]
 
 mod error;
 
-/// Element renderers.
+// The renderer is exposed so that it may be used by `daml-derive` only, it is not part of the public interface.
+#[doc(hidden)]
 pub mod renderer;
 
 /// Code generators for producing Rust implementations of Daml types.
